@@ -353,14 +353,4 @@ def test_main(cur):
     runner_wrapper(runner, base_options, ['--hierarchical-join', '--save-json-summary'])
 
     Path('x_table_report.html').unlink()
-
-
-# if __name__ == '__main__':
-#     os.environ['VERTICA_HOST'] = 'localhost'
-#     os.environ['VERTICA_PORT'] = '5433'
-#     os.environ['VERTICA_DATABASE'] = 'docker'
-#     os.environ['VERTICA_USERNAME'] = 'dbadmin'
-#     os.environ['VERTICA_PASSWORD'] = ''
-#     with get_cur() as c:
-#         test_main(c)
-
+    Path('x_table_diff_summary.json').unlink()
